# AnalysisResultResponseMetadata

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**analyzer** | **str** | Analyzer name which handled analysis. |
**analyzer_version** | **str** | Version of analyzer handling analysis. |
**arguments** | **object** | Arguments passed to analyzer. |
**_datetime** | **str** | Date and time of analysis end in ISO format. |
**distribution** | [**AnalysisResultResponseMetadataDistribution**](AnalysisResultResponseMetadataDistribution.md) |  |
**hostname** | **str** | Pod name where the analysis was done. |
**python** | [**AnalysisResultResponseMetadataPython**](AnalysisResultResponseMetadataPython.md) |  |

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)
